@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/compiled-esm-only-named/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/compiled-esm-only-named/input.js?commonjs-exports";
 
 Object.defineProperty(input, '__esModule', { value: true });
 var foo = input.foo = 'bar';
