@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/constant-template-literal/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/constant-template-literal/input.js?commonjs-exports";
 import require$$0 from "\u0000CWD/fixtures/form/constant-template-literal/tape.js?commonjs-proxy";
 
 var foo = require$$0;
