@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/defaultIsModuleExports-true-__esModule/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/defaultIsModuleExports-true-__esModule/input.js?commonjs-exports";
 
 input.__esModule = true;
 var _default = input.default = 2;
