@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/defaultIsModuleExports-true-no-__esModule/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/defaultIsModuleExports-true-no-__esModule/input.js?commonjs-exports";
 
 var _default = input.default = 2;
 var named = input.named = 3;
