@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/multiple-var-declarations-b/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/multiple-var-declarations-b/input.js?commonjs-exports";
 import require$$0 from "\u0000CWD/fixtures/form/multiple-var-declarations-b/a.js?commonjs-proxy";
 
 var a = require$$0
