@@ -1,5 +1,5 @@
 import * as commonjsHelpers from "_commonjsHelpers.js";
-import { __exports as input } from "\u0000fixtures/form/multiple-var-declarations/input.js?commonjs-exports"
+import { __exports as input } from "\u0000fixtures/form/multiple-var-declarations/input.js?commonjs-exports";
 import require$$0 from "\u0000CWD/fixtures/form/multiple-var-declarations/a.js?commonjs-proxy";
 import require$$1 from "\u0000CWD/fixtures/form/multiple-var-declarations/b.js?commonjs-proxy";
 
