@@ -2,5 +2,5 @@ import * as commonjsHelpers from "_commonjsHelpers.js";
 
 var input = function foo () {};
 
-export default input;
+export default /*@__PURE__*/commonjsHelpers.getDefaultExportFromCjs(input);
 export { input as __moduleExports };
